Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AlphaSlider ¶
type AlphaSlider struct {
// contains filtered or unexported fields
}
func NewAlphaSlider ¶
func NewAlphaSlider() *AlphaSlider
func (*AlphaSlider) Changed ¶
func (s *AlphaSlider) Changed() bool
func (*AlphaSlider) Color ¶
func (s *AlphaSlider) Color() color.NRGBA
func (*AlphaSlider) Layout ¶
func (s *AlphaSlider) Layout(gtx layout.Context) layout.Dimensions
func (*AlphaSlider) SetColor ¶
func (s *AlphaSlider) SetColor(col color.NRGBA)
type ColorInput ¶
type ColorSelection ¶
type ColorSelection struct {
Dropdown layout.Direction
CornerRadius unit.Value
Inset layout.Inset
Input *Mux
// contains filtered or unexported fields
}
func NewColorSelection ¶
func NewColorSelection(th *material.Theme, drop layout.Direction, inputs ...ColorInput) *ColorSelection
func (*ColorSelection) Changed ¶
func (cf *ColorSelection) Changed() bool
func (*ColorSelection) Color ¶
func (cf *ColorSelection) Color() color.NRGBA
func (*ColorSelection) Layout ¶
func (cf *ColorSelection) Layout(gtx layout.Context) layout.Dimensions
func (*ColorSelection) SetColor ¶
func (cf *ColorSelection) SetColor(col color.NRGBA)
type HSVColor ¶
type HSVColor struct {
// H stands for hue and is the rgb portion of the model,
// expressed as a number from 0 to 360 degrees:
// Red falls between 0 and 60 degrees.
// Yellow falls between 61 and 120 degrees.
// Green falls between 121 and 180 degrees.
// Cyan falls between 181 and 240 degrees.
// Blue falls between 241 and 300 degrees.
// Magenta falls between 301 and 360 degrees.
H float32
// S stands for saturation and describes the amount of gray in a particular rgb,from 0 to 1.
// Reducing this component toward zero introduces more gray and produces a faded effect.
S float32
// V stands for value and works in conjunction with saturation and describes the brightness or intensity of the rgb,
// from 0 to 1, where 0 is completely black, and 1 is the brightest and reveals the most rgb.
V float32
}
HSV is a cylindrical rgb model that remaps the RGB primary colors into dimensions that are easier for humans to understand.
type HexEditor ¶
type HexEditor struct {
// contains filtered or unexported fields
}
func NewHexEditor ¶
type HsvEditor ¶
type HsvEditor struct {
// contains filtered or unexported fields
}
func NewHsvEditor ¶
type Mux ¶
type Mux struct {
// contains filtered or unexported fields
}
func NewMux ¶
func NewMux(inputs ...ColorInput) *Mux
type Position ¶
func (*Position) Changed ¶
Changed reports whether the value has changed since the last call to Changed.
type RgbEditor ¶
type RgbEditor struct {
// contains filtered or unexported fields
}
func NewRgbEditor ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.